Use Case: Creating a CMF Folder
===============================

  Actor

    - Site Manager

  Overview

    Folders may used in CMF to help organize content. Folders may contain
    any kind of content object, including subfolders.

  Assumptions

    - Foo

  Procedure

    To create a new Folder at a given place in the site heirarchy, navigate
    to the place where you want to add the new Folder, then click the
    "Folder Contents" link in the actions box. This will bring up the
    "desktop" view of the current Folder, listing the content objects
    and subfolders. In the desktop view, click the "New..." button.

    You will now see the "Add Content" form. This form provides a list of
    the kinds of objects you can add at this location (based on the
    permissions you have), and descriptions of the available objects.

    Select "Folder" from the listing, enter an id for the new folder in
    the "id" field located below the listing of available object, and
    click the "Add" button to add the new Folder.

    After submitting the add form, you will be taken to the "desktop" view
    of the newly created Folder.

  Notes

    - This use case is not specific to a Site Manager;  it is
      properly a Content Creator use case.
